# AUTOGENERATED! DO NOT EDIT! File to edit: ../nbs/00_cons.ipynb.

# %% auto 0
__all__ = ['RATE_LIMIT', 'RETRY', 'RETRY_AFTER', 'CONTENT_TYPE', 'ENSEMBL_SERVER']

# %% ../nbs/00_cons.ipynb 4
#| export


# %% ../nbs/00_cons.ipynb 6
RATE_LIMIT = 15
RETRY = 'retry'
RETRY_AFTER = 'Retry-After'
CONTENT_TYPE = 'Content-Type'
ENSEMBL_SERVER = 'http://rest.ensembl.org'
