# Autogenerated by nbdev

d = { 'settings': { 'branch': 'main',
                'doc_baseurl': '/ensc',
                'doc_host': 'https://dsm-72.github.io',
                'git_url': 'https://github.com/dsm-72/ensc',
                'lib_path': 'ensc'},
  'syms': { 'ensc.cons': {},
            'ensc.data': { 'ensc.data.GeneInfo': ('data.html#geneinfo', 'ensc/data.py'),
                           'ensc.data.GeneInfo.__call__': ('data.html#geneinfo.__call__', 'ensc/data.py'),
                           'ensc.data.GeneInfo.lookup': ('data.html#geneinfo.lookup', 'ensc/data.py')},
            'ensc.ensc': { 'ensc.ensc.EnsemblClient': ('ensc.html#ensemblclient', 'ensc/ensc.py'),
                           'ensc.ensc.EnsemblClient.getids': ('ensc.html#ensemblclient.getids', 'ensc/ensc.py'),
                           'ensc.ensc.EnsemblClient.lookup': ('ensc.html#ensemblclient.lookup', 'ensc/ensc.py'),
                           'ensc.ensc.EnsemblClient.request': ('ensc.html#ensemblclient.request', 'ensc/ensc.py')},
            'ensc.errs': { 'ensc.errs.RateLimitError': ('errs.html#ratelimiterror', 'ensc/errs.py'),
                           'ensc.errs.RateLimitError.__init__': ('errs.html#ratelimiterror.__init__', 'ensc/errs.py'),
                           'ensc.errs.RateLimitError.handle': ('errs.html#ratelimiterror.handle', 'ensc/errs.py')},
            'ensc.reqs': { 'ensc.reqs.JSONRequest': ('reqs.html#jsonrequest', 'ensc/reqs.py'),
                           'ensc.reqs.JSONRequest.__call__': ('reqs.html#jsonrequest.__call__', 'ensc/reqs.py'),
                           'ensc.reqs.JSONRequest.__init__': ('reqs.html#jsonrequest.__init__', 'ensc/reqs.py'),
                           'ensc.reqs.JSONRequest.add_query': ('reqs.html#jsonrequest.add_query', 'ensc/reqs.py'),
                           'ensc.reqs.JSONRequest.request': ('reqs.html#jsonrequest.request', 'ensc/reqs.py'),
                           'ensc.reqs.RateLimitRequest': ('reqs.html#ratelimitrequest', 'ensc/reqs.py'),
                           'ensc.reqs.RateLimitRequest.__call__': ('reqs.html#ratelimitrequest.__call__', 'ensc/reqs.py'),
                           'ensc.reqs.RateLimitRequest.__init__': ('reqs.html#ratelimitrequest.__init__', 'ensc/reqs.py')},
            'ensc.util': { 'ensc.util.RateLimiter': ('util.html#ratelimiter', 'ensc/util.py'),
                           'ensc.util.RateLimiter.__call__': ('util.html#ratelimiter.__call__', 'ensc/util.py'),
                           'ensc.util.RateLimiter.__init__': ('util.html#ratelimiter.__init__', 'ensc/util.py'),
                           'ensc.util.RateLimiter.__repr__': ('util.html#ratelimiter.__repr__', 'ensc/util.py'),
                           'ensc.util.Singleton': ('util.html#singleton', 'ensc/util.py'),
                           'ensc.util.Singleton.__call__': ('util.html#singleton.__call__', 'ensc/util.py')}}}
